dag_cbor.ipld
=============

.. automodule:: dag_cbor.ipld

IPLDKind
--------

.. autodata:: dag_cbor.ipld.IPLDKind

IPLDObjPath
-----------

.. autoclass:: dag_cbor.ipld.IPLDObjPath
    :show-inheritance:
    :members:
    :special-members: __new__, __truediv__, __rtruediv__, __le__, __lt__, __repr__, __rshift__

IPLDObjPathSegment
------------------

.. autodata:: dag_cbor.ipld.IPLDObjPathSegment

IPLDScalarKind
--------------

.. autodata:: dag_cbor.ipld.IPLDScalarKind
